==> odata-client-microsoft-dynamics-0.1.89-sources.jar: microsoft/dynamics/crm/complex/RetrieveAllEntitiesResponse.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "EntityMetadata", 
    "Timestamp"})
@JsonInclude(Include.NON_NULL)
public class RetrieveAllEntitiesResponse implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("EntityMetadata")
    protected List<ComplexEntityMetadata> entityMetadata;

    @JsonProperty("EntityMetadata@nextLink")
    protected String entityMetadataNextLink;

    @JsonProperty("Timestamp")
    protected String timestamp;

    protected RetrieveAllEntitiesResponse() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.RetrieveAllEntitiesResponse";
    }

    @Property(name="EntityMetadata")
    @JsonIgnore
    public CollectionPage<ComplexEntityMetadata> getEntityMetadata() {
        return new CollectionPage<ComplexEntityMetadata>(contextPath, ComplexEntityMetadata.class, this.entityMetadata, Optional.ofNullable(entityMetadataNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="EntityMetadata")
    @JsonIgnore
    public CollectionPage<ComplexEntityMetadata> getEntityMetadata(HttpRequestOptions options) {
        return new CollectionPage<ComplexEntityMetadata>(contextPath, ComplexEntityMetadata.class, this.entityMetadata, Optional.ofNullable(entityMetadataNextLink), Collections.emptyList(), options);
    }

    @Property(name="Timestamp")
    @JsonIgnore
    public Optional<String> getTimestamp() {
        return Optional.ofNullable(timestamp);
    }

    public RetrieveAllEntitiesResponse withTimestamp(String timestamp) {
        Checks.checkIsAscii(timestamp);
        RetrieveAllEntitiesResponse _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.RetrieveAllEntitiesResponse");
        _x.timestamp = timestamp;
        return _x;
    }

    public RetrieveAllEntitiesResponse withUnmappedField(String name, String value) {
        RetrieveAllEntitiesResponse _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private List<ComplexEntityMetadata> entityMetadata;
        private String entityMetadataNextLink;
        private String timestamp;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder entityMetadata(List<ComplexEntityMetadata> entityMetadata) {
            this.entityMetadata = entityMetadata;
            this.changedFields = changedFields.add("EntityMetadata");
            return this;
        }

        public Builder entityMetadata(ComplexEntityMetadata... entityMetadata) {
            return entityMetadata(Arrays.asList(entityMetadata));
        }

        public Builder entityMetadataNextLink(String entityMetadataNextLink) {
            this.entityMetadataNextLink = entityMetadataNextLink;
            this.changedFields = changedFields.add("EntityMetadata");
            return this;
        }

        public Builder timestamp(String timestamp) {
            this.timestamp = timestamp;
            this.changedFields = changedFields.add("Timestamp");
            return this;
        }

        public RetrieveAllEntitiesResponse build() {
            RetrieveAllEntitiesResponse _x = new RetrieveAllEntitiesResponse();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.RetrieveAllEntitiesResponse";
            _x.entityMetadata = entityMetadata;
            _x.entityMetadataNextLink = entityMetadataNextLink;
            _x.timestamp = timestamp;
            return _x;
        }
    }

    private RetrieveAllEntitiesResponse _copy() {
        RetrieveAllEntitiesResponse _x = new RetrieveAllEntitiesResponse();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.entityMetadata = entityMetadata;
        _x.timestamp = timestamp;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("RetrieveAllEntitiesResponse[");
        b.append("EntityMetadata=");
        b.append(this.entityMetadata);
        b.append(", ");
        b.append("Timestamp=");
        b.append(this.timestamp);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-microsoft-dynamics-0.1.93-sources.jar: microsoft/dynamics/crm/complex/RetrieveAllEntitiesResponse.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "EntityMetadata", 
    "Timestamp"})
@JsonInclude(Include.NON_NULL)
public class RetrieveAllEntitiesResponse implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("EntityMetadata")
    protected List<ComplexEntityMetadata> entityMetadata;

    @JsonProperty("EntityMetadata@nextLink")
    protected String entityMetadataNextLink;

    @JsonProperty("Timestamp")
    protected String timestamp;

    protected RetrieveAllEntitiesResponse() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.RetrieveAllEntitiesResponse";
    }

    @Property(name="EntityMetadata")
    @JsonIgnore
    public CollectionPage<ComplexEntityMetadata> getEntityMetadata() {
        return new CollectionPage<ComplexEntityMetadata>(contextPath, ComplexEntityMetadata.class, this.entityMetadata, Optional.ofNullable(entityMetadataNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="EntityMetadata")
    @JsonIgnore
    public CollectionPage<ComplexEntityMetadata> getEntityMetadata(HttpRequestOptions options) {
        return new CollectionPage<ComplexEntityMetadata>(contextPath, ComplexEntityMetadata.class, this.entityMetadata, Optional.ofNullable(entityMetadataNextLink), Collections.emptyList(), options);
    }

    @Property(name="Timestamp")
    @JsonIgnore
    public Optional<String> getTimestamp() {
        return Optional.ofNullable(timestamp);
    }

    public RetrieveAllEntitiesResponse withTimestamp(String timestamp) {
        RetrieveAllEntitiesResponse _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.RetrieveAllEntitiesResponse");
        _x.timestamp = timestamp;
        return _x;
    }

    public RetrieveAllEntitiesResponse withUnmappedField(String name, Object value) {
        RetrieveAllEntitiesResponse _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private List<ComplexEntityMetadata> entityMetadata;
        private String entityMetadataNextLink;
        private String timestamp;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder entityMetadata(List<ComplexEntityMetadata> entityMetadata) {
            this.entityMetadata = entityMetadata;
            this.changedFields = changedFields.add("EntityMetadata");
            return this;
        }

        public Builder entityMetadata(ComplexEntityMetadata... entityMetadata) {
            return entityMetadata(Arrays.asList(entityMetadata));
        }

        public Builder entityMetadataNextLink(String entityMetadataNextLink) {
            this.entityMetadataNextLink = entityMetadataNextLink;
            this.changedFields = changedFields.add("EntityMetadata");
            return this;
        }

        public Builder timestamp(String timestamp) {
            this.timestamp = timestamp;
            this.changedFields = changedFields.add("Timestamp");
            return this;
        }

        public RetrieveAllEntitiesResponse build() {
            RetrieveAllEntitiesResponse _x = new RetrieveAllEntitiesResponse();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.RetrieveAllEntitiesResponse";
            _x.entityMetadata = entityMetadata;
            _x.entityMetadataNextLink = entityMetadataNextLink;
            _x.timestamp = timestamp;
            return _x;
        }
    }

    private RetrieveAllEntitiesResponse _copy() {
        RetrieveAllEntitiesResponse _x = new RetrieveAllEntitiesResponse();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.entityMetadata = entityMetadata;
        _x.timestamp = timestamp;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("RetrieveAllEntitiesResponse[");
        b.append("EntityMetadata=");
        b.append(this.entityMetadata);
        b.append(", ");
        b.append("Timestamp=");
        b.append(this.timestamp);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
